@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 # author: Ethosa
 
-from .CSharpToCppTranslator import CSharpToCppTranslator
+from .CSharpToCpp import CSharpToCpp
 
-__version__ = "0.0.6"
+__version__ = "0.0.7"
 __copyright__ = "2019"
 __authors__ = ["Ethosa", "Konard"]
\ No newline at end of file
